@@ -31,7 +31,6 @@ def get_input_mode():
 
     url_to_analyze = ""
     src_path = ""
-    dep_path = ""
     dep_arguments = ""
 
     if ask_to_run("What are you going to analyze? (1/2)\n\
@@ -40,9 +39,8 @@ def get_input_mode():
         url_to_analyze = get_input("Enter the link to analyze:", "")
     else:
         src_path = get_input("Please enter the path to analyze:", "")
-        dep_path = src_path
 
         dep_arguments = get_input(
             "Please enter arguments for dependency analysis:", "")
 
-    return src_path, dep_path, dep_arguments, url_to_analyze
+    return src_path, dep_arguments, url_to_analyze
